@@ -864,7 +864,7 @@ def run_sfsp_cmd(stage, region, app_dir, traits_input_file, traits_output_file):
 @cli.command("run-test")
 @click.option('-s', '--stage', required=True, type=str, help='Deployment stage')
 @click.option('--traits-input-file', type=click.Path(exists=True, file_okay=True, dir_okay=False, writable=True), default='traits.yml', help='Load traits file. Default (traits.yml)')
-def run_test_cmd(stage, traits_input_file, traits_output_file):
+def run_test_cmd(stage, traits_input_file):
     app = load_traits_from_file(traits_input_file, default_service_yaml_schema)
 
     run_test_checks(app, stage)
@@ -879,7 +879,7 @@ def run_test_cmd(stage, traits_input_file, traits_output_file):
 @cli.command("run-lint")
 @click.option('-s', '--stage', required=True, type=str, help='Deployment stage')
 @click.option('--traits-input-file', type=click.Path(exists=True, file_okay=True, dir_okay=False, writable=True), default='traits.yml', help='Load traits file. Default (traits.yml)')
-def run_lint_cmd(stage, traits_input_file, traits_output_file):
+def run_lint_cmd(stage, traits_input_file):
     app = load_traits_from_file(traits_input_file, default_service_yaml_schema)
 
     run_lint_checks(app, stage)
